Class: Google::Cloud::Appoptimize::V1beta::AppOptimize::Rest::Client
- Inherits:
-
Object
- Object
- Google::Cloud::Appoptimize::V1beta::AppOptimize::Rest::Client
- Includes:
- Paths
- Defined in:
- lib/google/cloud/appoptimize/v1beta/app_optimize/rest/client.rb
Overview
REST client for the AppOptimize service.
Service for managing and querying optimization reports.
Defined Under Namespace
Classes: Configuration
Instance Attribute Summary collapse
-
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client
readonly
Get the associated client for mix-in of the Locations.
-
#operations_client ⇒ ::Google::Cloud::Appoptimize::V1beta::AppOptimize::Rest::Operations
readonly
Get the associated client for long-running operations.
Class Method Summary collapse
-
.configure {|config| ... } ⇒ Client::Configuration
Configure the AppOptimize Client class.
Instance Method Summary collapse
-
#configure {|config| ... } ⇒ Client::Configuration
Configure the AppOptimize Client instance.
-
#create_report(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Operation
Creates a new report.
-
#delete_report(request, options = nil) {|result, operation| ... } ⇒ ::Google::Protobuf::Empty
Deletes the specified report.
-
#get_report(request, options = nil) {|result, operation| ... } ⇒ ::Google::Cloud::Appoptimize::V1beta::Report
Retrieves the details of a report configuration.
-
#initialize {|config| ... } ⇒ Client
constructor
Create a new AppOptimize REST client object.
-
#list_reports(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Appoptimize::V1beta::Report>
Lists reports within a given project.
-
#logger ⇒ Logger
The logger used for request/response debug logging.
-
#read_report(request, options = nil) {|result, operation| ... } ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Protobuf::ListValue>
Reads data within a specified report.
-
#universe_domain ⇒ String
The effective universe domain.
Methods included from Paths
#application_path, #location_path, #project_path, #report_path
Constructor Details
#initialize {|config| ... } ⇒ Client
Create a new AppOptimize REST client object.
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/google/cloud/appoptimize/v1beta/app_optimize/rest/client.rb', line 146 def initialize # Create the configuration object @config = Configuration.new Client.configure # Yield the configuration if needed yield @config if block_given? # Create credentials credentials = @config.credentials # Use self-signed JWT if the endpoint is unchanged from default, # but only if the default endpoint does not have a region prefix. enable_self_signed_jwt = @config.endpoint.nil? || (@config.endpoint == Configuration::DEFAULT_ENDPOINT && !@config.endpoint.split(".").first.include?("-")) credentials ||= Credentials.default scope: @config.scope, enable_self_signed_jwt: enable_self_signed_jwt if credentials.is_a?(::String) || credentials.is_a?(::Hash) credentials = Credentials.new credentials, scope: @config.scope end @quota_project_id = @config.quota_project @quota_project_id ||= credentials.quota_project_id if credentials.respond_to? :quota_project_id @operations_client = ::Google::Cloud::Appoptimize::V1beta::AppOptimize::Rest::Operations.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @config.endpoint config.universe_domain = @config.universe_domain end @app_optimize_stub = ::Google::Cloud::Appoptimize::V1beta::AppOptimize::Rest::ServiceStub.new( endpoint: @config.endpoint, endpoint_template: DEFAULT_ENDPOINT_TEMPLATE, universe_domain: @config.universe_domain, credentials: credentials, logger: @config.logger ) @app_optimize_stub.logger(stub: true)&.info do |entry| entry.set_system_name entry.set_service entry. = "Created client for #{entry.service}" entry.set_credentials_fields credentials entry.set "customEndpoint", @config.endpoint if @config.endpoint entry.set "defaultTimeout", @config.timeout if @config.timeout entry.set "quotaProject", @quota_project_id if @quota_project_id end @location_client = Google::Cloud::Location::Locations::Rest::Client.new do |config| config.credentials = credentials config.quota_project = @quota_project_id config.endpoint = @app_optimize_stub.endpoint config.universe_domain = @app_optimize_stub.universe_domain config.bindings_override = @config.bindings_override config.logger = @app_optimize_stub.logger if config.respond_to? :logger= end end |
Instance Attribute Details
#location_client ⇒ Google::Cloud::Location::Locations::Rest::Client (readonly)
Get the associated client for mix-in of the Locations.
216 217 218 |
# File 'lib/google/cloud/appoptimize/v1beta/app_optimize/rest/client.rb', line 216 def location_client @location_client end |
#operations_client ⇒ ::Google::Cloud::Appoptimize::V1beta::AppOptimize::Rest::Operations (readonly)
Get the associated client for long-running operations.
209 210 211 |
# File 'lib/google/cloud/appoptimize/v1beta/app_optimize/rest/client.rb', line 209 def operations_client @operations_client end |
Class Method Details
.configure {|config| ... } ⇒ Client::Configuration
Configure the AppOptimize Client class.
See Configuration for a description of the configuration fields.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/google/cloud/appoptimize/v1beta/app_optimize/rest/client.rb', line 65 def self.configure @configure ||= begin namespace = ["Google", "Cloud", "Appoptimize", "V1beta"] parent_config = while namespace.any? parent_name = namespace.join "::" parent_const = const_get parent_name break parent_const.configure if parent_const.respond_to? :configure namespace.pop end default_config = Client::Configuration.new parent_config default_config.rpcs.create_report.timeout = 60.0 default_config.rpcs.get_report.timeout = 60.0 default_config.rpcs.get_report.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.list_reports.timeout = 60.0 default_config.rpcs.list_reports.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config.rpcs.delete_report.timeout = 60.0 default_config.rpcs.read_report.timeout = 60.0 default_config.rpcs.read_report.retry_policy = { initial_delay: 1.0, max_delay: 10.0, multiplier: 1.3, retry_codes: [14] } default_config end yield @configure if block_given? @configure end |
Instance Method Details
#configure {|config| ... } ⇒ Client::Configuration
Configure the AppOptimize Client instance.
The configuration is set to the derived mode, meaning that values can be changed, but structural changes (adding new fields, etc.) are not allowed. Structural changes should be made on configure.
See Configuration for a description of the configuration fields.
116 117 118 119 |
# File 'lib/google/cloud/appoptimize/v1beta/app_optimize/rest/client.rb', line 116 def configure yield @config if block_given? @config end |
#create_report(request, options = nil) ⇒ ::Gapic::Operation #create_report(parent: nil, report_id: nil, report: nil) ⇒ ::Gapic::Operation
Creates a new report.
This initiates a long-running operation that, upon completion, results
in a report resource. Once the report is created, its results can be read
via ReadReport.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/google/cloud/appoptimize/v1beta/app_optimize/rest/client.rb', line 295 def create_report request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Appoptimize::V1beta::CreateReportRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.create_report..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::AppOptimize::V1beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.create_report.timeout, metadata: , retry_policy: @config.rpcs.create_report.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @app_optimize_stub.create_report request, do |result, operation| result = ::Gapic::Operation.new result, @operations_client, options: yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#delete_report(request, options = nil) ⇒ ::Google::Protobuf::Empty #delete_report(name: nil, allow_missing: nil) ⇒ ::Google::Protobuf::Empty
Deletes the specified report.
556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 |
# File 'lib/google/cloud/appoptimize/v1beta/app_optimize/rest/client.rb', line 556 def delete_report request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Appoptimize::V1beta::DeleteReportRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.delete_report..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::AppOptimize::V1beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.delete_report.timeout, metadata: , retry_policy: @config.rpcs.delete_report.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @app_optimize_stub.delete_report request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#get_report(request, options = nil) ⇒ ::Google::Cloud::Appoptimize::V1beta::Report #get_report(name: nil) ⇒ ::Google::Cloud::Appoptimize::V1beta::Report
Retrieves the details of a report configuration.
377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 |
# File 'lib/google/cloud/appoptimize/v1beta/app_optimize/rest/client.rb', line 377 def get_report request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Appoptimize::V1beta::GetReportRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.get_report..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::AppOptimize::V1beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.get_report.timeout, metadata: , retry_policy: @config.rpcs.get_report.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @app_optimize_stub.get_report request, do |result, operation| yield result, operation if block_given? end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#list_reports(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Appoptimize::V1beta::Report> #list_reports(parent: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Cloud::Appoptimize::V1beta::Report>
Lists reports within a given project.
471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 |
# File 'lib/google/cloud/appoptimize/v1beta/app_optimize/rest/client.rb', line 471 def list_reports request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Appoptimize::V1beta::ListReportsRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.list_reports..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::AppOptimize::V1beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.list_reports.timeout, metadata: , retry_policy: @config.rpcs.list_reports.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @app_optimize_stub.list_reports request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @app_optimize_stub, :list_reports, "reports", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#logger ⇒ Logger
The logger used for request/response debug logging.
223 224 225 |
# File 'lib/google/cloud/appoptimize/v1beta/app_optimize/rest/client.rb', line 223 def logger @app_optimize_stub.logger end |
#read_report(request, options = nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Protobuf::ListValue> #read_report(name: nil, page_size: nil, page_token: nil) ⇒ ::Gapic::Rest::PagedEnumerable<::Google::Protobuf::ListValue>
Reads data within a specified report.
650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 |
# File 'lib/google/cloud/appoptimize/v1beta/app_optimize/rest/client.rb', line 650 def read_report request, = nil raise ::ArgumentError, "request must be provided" if request.nil? request = ::Gapic::Protobuf.coerce request, to: ::Google::Cloud::Appoptimize::V1beta::ReadReportRequest # Converts hash and nil to an options object = ::Gapic::CallOptions.new(**.to_h) if .respond_to? :to_h # Customize the options with defaults = @config.rpcs.read_report..to_h # Set x-goog-api-client, x-goog-user-project and x-goog-api-version headers [:"x-goog-api-client"] ||= ::Gapic::Headers.x_goog_api_client \ lib_name: @config.lib_name, lib_version: @config.lib_version, gapic_version: ::Google::Cloud::AppOptimize::V1beta::VERSION, transports_version_send: [:rest] [:"x-goog-api-version"] = API_VERSION unless API_VERSION.empty? [:"x-goog-user-project"] = @quota_project_id if @quota_project_id .apply_defaults timeout: @config.rpcs.read_report.timeout, metadata: , retry_policy: @config.rpcs.read_report.retry_policy .apply_defaults timeout: @config.timeout, metadata: @config., retry_policy: @config.retry_policy @app_optimize_stub.read_report request, do |result, operation| result = ::Gapic::Rest::PagedEnumerable.new @app_optimize_stub, :read_report, "rows", request, result, yield result, operation if block_given? throw :response, result end rescue ::Gapic::Rest::Error => e raise ::Google::Cloud::Error.from_error(e) end |
#universe_domain ⇒ String
The effective universe domain
126 127 128 |
# File 'lib/google/cloud/appoptimize/v1beta/app_optimize/rest/client.rb', line 126 def universe_domain @app_optimize_stub.universe_domain end |