Class: Google::Cloud::Appoptimize::V1beta::CreateReportRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb

Overview

Request message for the CreateReport method.

Instance Attribute Summary collapse

Instance Attribute Details

#parent::String

Returns Required. The parent Google Cloud project that will own the report.

This value does not define the scope of the report data. See Report.scope for setting the data scope.

Format: projects/{project}/locations/{location}.

Returns:

  • (::String)

    Required. The parent Google Cloud project that will own the report.

    This value does not define the scope of the report data. See Report.scope for setting the data scope.

    Format: projects/{project}/locations/{location}.



42
43
44
45
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 42

class CreateReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#report::Google::Cloud::Appoptimize::V1beta::Report

Returns Required. The report resource to create.

Returns:



42
43
44
45
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 42

class CreateReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#report_id::String

Returns Required. The ID to use for this report. This ID must be unique within the parent project and should comply with RFC 1034 restrictions (letters, numbers, and hyphen, with the first character a letter, the last a letter or a number, and a 63 character maximum).

Returns:

  • (::String)

    Required. The ID to use for this report. This ID must be unique within the parent project and should comply with RFC 1034 restrictions (letters, numbers, and hyphen, with the first character a letter, the last a letter or a number, and a 63 character maximum).



42
43
44
45
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 42

class CreateReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end