Class: Google::Cloud::Appoptimize::V1beta::DeleteReportRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb

Overview

Request message for the DeleteReport method.

Instance Attribute Summary collapse

Instance Attribute Details

#allow_missing::Boolean

Returns Optional. If set to true, and the report is not found, the request will succeed but no action will be taken on the server.

Returns:

  • (::Boolean)

    Optional. If set to true, and the report is not found, the request will succeed but no action will be taken on the server.



230
231
232
233
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 230

class DeleteReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns Required. The name of the report to delete.

Format: projects/{project}/locations/{location}/reports/{report_id}.

Returns:

  • (::String)

    Required. The name of the report to delete.

    Format: projects/{project}/locations/{location}/reports/{report_id}.



230
231
232
233
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 230

class DeleteReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end