Class: Google::Cloud::Appoptimize::V1beta::ReadReportRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb

Overview

Request message for the ReadReport method.

Instance Attribute Summary collapse

Instance Attribute Details

#name::String

Returns Required. The resource name of the report to query.

Format: projects/{project}/locations/{location}/reports/{report_id}.

Returns:

  • (::String)

    Required. The resource name of the report to query.

    Format: projects/{project}/locations/{location}/reports/{report_id}.



253
254
255
256
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 253

class ReadReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns Optional. The maximum number of rows to return. The service may return fewer than this value. If unspecified, at most 10,000 rows will be returned per page. The maximum allowed value is 25,000; values above 25,000 are coerced to 25,000.

Returns:

  • (::Integer)

    Optional. The maximum number of rows to return. The service may return fewer than this value. If unspecified, at most 10,000 rows will be returned per page. The maximum allowed value is 25,000; values above 25,000 are coerced to 25,000.



253
254
255
256
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 253

class ReadReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns Optional. A page token, received from a previous ReadReport call, to retrieve the subsequent page of results. When page_token is specified, job_reference must also be provided from the previous response, and the statement field must not be set.

Returns:

  • (::String)

    Optional. A page token, received from a previous ReadReport call, to retrieve the subsequent page of results. When page_token is specified, job_reference must also be provided from the previous response, and the statement field must not be set.



253
254
255
256
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 253

class ReadReportRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end