Class: Google::Cloud::Appoptimize::V1beta::ReadReportResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb

Overview

Response message for the ReadReport method.

Instance Attribute Summary collapse

Instance Attribute Details

#columns::Array<::Google::Cloud::Appoptimize::V1beta::Column>

Returns The columns describing the structure of the data in the rows field.

Returns:



270
271
272
273
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 270

class ReadReportResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns A token that can be sent as page_token in a subsequent ReadReport request to retrieve the next page of results. If this field is empty, there are no further pages.

Returns:

  • (::String)

    A token that can be sent as page_token in a subsequent ReadReport request to retrieve the next page of results. If this field is empty, there are no further pages.



270
271
272
273
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 270

class ReadReportResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#rows::Array<::Google::Protobuf::ListValue>

Returns A list of rows, where each row represents a record from the report.

Returns:



270
271
272
273
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 270

class ReadReportResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end