Class: Google::Cloud::Appoptimize::V1beta::Column

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb

Overview

Describes a single column within Columns.

Instance Attribute Summary collapse

Instance Attribute Details

#columns::Array<::Google::Cloud::Appoptimize::V1beta::Column>

Returns If the type of this column is RECORD, this sub-field describes the nested structure.

Returns:



314
315
316
317
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 314

class Column
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#mode::String

Returns The mode of the column, indicating if it is nullable, required, or repeated.

Possible values:

  • NULLABLE: The column allows NULL values.
  • REQUIRED: The column does not allow NULL values.
  • REPEATED: The column contains an array of values.

Returns:

  • (::String)

    The mode of the column, indicating if it is nullable, required, or repeated.

    Possible values:

    • NULLABLE: The column allows NULL values.
    • REQUIRED: The column does not allow NULL values.
    • REPEATED: The column contains an array of values.


314
315
316
317
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 314

class Column
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#name::String

Returns The name of the column.

This field:

  • Contains only letters (a-z, A-Z), numbers (0-9), or underscores (_);
  • Start with a letter or underscore; and
  • Has a maximum length is 128 characters.

Returns:

  • (::String)

    The name of the column.

    This field:

    • Contains only letters (a-z, A-Z), numbers (0-9), or underscores (_);
    • Start with a letter or underscore; and
    • Has a maximum length is 128 characters.


314
315
316
317
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 314

class Column
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#type::String

Returns The data type of the column.

Supported values include:

  • STRING
  • INT64
  • FLOAT64
  • BOOLEAN
  • TIMESTAMP
  • RECORD

RECORD indicates that the field contains a nested schema, described in the columns property of this Column.

Returns:

  • (::String)

    The data type of the column.

    Supported values include:

    • STRING
    • INT64
    • FLOAT64
    • BOOLEAN
    • TIMESTAMP
    • RECORD

    RECORD indicates that the field contains a nested schema, described in the columns property of this Column.



314
315
316
317
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 314

class Column
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end