Class: Google::Cloud::Appoptimize::V1beta::ListReportsRequest
- Inherits:
-
Object
- Object
- Google::Cloud::Appoptimize::V1beta::ListReportsRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb
Overview
Request message for the ListReports method.
Instance Attribute Summary collapse
-
#page_size ⇒ ::Integer
Optional.
-
#page_token ⇒ ::String
Optional.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#page_size ⇒ ::Integer
Returns Optional. The maximum number of reports to return. The service may return fewer than this value. If unspecified, the server will determine the number of results to return.
202 203 204 205 |
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 202 class ListReportsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns Optional. A page token, received from a previous ListReports call.
Provide this to retrieve the subsequent page.
When paginating, all other parameters provided to ListReports must match
the call that provided the page token.
202 203 204 205 |
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 202 class ListReportsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The parent project whose reports are to be listed.
Format: projects/{project}/locations/{location}.
202 203 204 205 |
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 202 class ListReportsRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |