Class: Google::Cloud::Appoptimize::V1beta::Scope
- Inherits:
-
Object
- Object
- Google::Cloud::Appoptimize::V1beta::Scope
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb
Overview
Specifies the report scope.
Instance Attribute Summary collapse
-
#application ⇒ ::String
Required.
-
#project ⇒ ::String
Required.
Instance Attribute Details
#application ⇒ ::String
Returns Required. An App Hub Application to fetch data from.
Format:
"projects/{project}/locations/{location}/applications/{application}".
Note: The following fields are mutually exclusive: application, project. If a field in that set is populated, all other fields in the set will automatically be cleared.
168 169 170 171 |
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 168 class Scope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#project ⇒ ::String
Returns Required. A Google Cloud Platform project to fetch data from.
Format: "projects/{project}".
Note: The following fields are mutually exclusive: project, application. If a field in that set is populated, all other fields in the set will automatically be cleared.
168 169 170 171 |
# File 'proto_docs/google/cloud/appoptimize/v1beta/app_optimize.rb', line 168 class Scope include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |